summaryrefslogtreecommitdiffstats
path: root/macosx/Controller.mm
diff options
context:
space:
mode:
Diffstat (limited to 'macosx/Controller.mm')
-rw-r--r--macosx/Controller.mm8
1 files changed, 4 insertions, 4 deletions
diff --git a/macosx/Controller.mm b/macosx/Controller.mm
index 38ff91540..46049cdc5 100644
--- a/macosx/Controller.mm
+++ b/macosx/Controller.mm
@@ -1565,14 +1565,14 @@ static NSString * ChooseSourceIdentifier = @"Choose Source It
- (void) removeQueueFileItem:(int) queueItemToRemove
{
- /* Find out if the item we are removing is a cancelled item*/
- if ([[[QueueFileArray objectAtIndex:queueItemToRemove] objectForKey:@"Status"] intValue] == 3)
+ /* Find out if the item we are removing is a cancelled (3) or a finished (0) item*/
+ if ([[[QueueFileArray objectAtIndex:queueItemToRemove] objectForKey:@"Status"] intValue] == 3 || [[[QueueFileArray objectAtIndex:queueItemToRemove] objectForKey:@"Status"] intValue] == 0)
{
/* Since we are removing a cancelled item, WE need to decrement the currentQueueEncodeIndex
* by one to keep in sync with the queue array
*/
currentQueueEncodeIndex--;
- [self writeToActivityLog: "removeQueueFileItem: Removing a cancelled encode, decrement currentQueueEncodeIndex to %d", currentQueueEncodeIndex];
+ [self writeToActivityLog: "removeQueueFileItem: Removing a cancelled/finished encode, decrement currentQueueEncodeIndex to %d", currentQueueEncodeIndex];
}
[QueueFileArray removeObjectAtIndex:queueItemToRemove];
[self saveQueueFileItem];
@@ -1565,14 +1565,14 @@ static NSString * ChooseSourceIdentifier = @"Choose Source It
{
- /* Since we are removing a cancelled item, WE need to decrement the currentQueueEncodeIndex
+ /* Since we are removing a cancelled or finished item, WE need to decrement the currentQueueEncodeIndex
* by one to keep in sync with the queue array
*/